Struct HvxVector
Source pub struct HvxVector();
๐ฌThis is a nightly-only experimental API. (stdarch_hexagon #151523) Available on target_arch=hexagon only.
HVX vector type (1024 bits / 128 bytes)
This type represents a single HVX vector register containing 32 x 32-bit values.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.