pub struct HvxVectorPred(/* private fields */);๐ฌThis is a nightly-only experimental API. (
stdarch_hexagon #151523)Available on
target_arch=hexagon only.Expand description
HVX vector predicate type (1024 bits / 128 bytes)
This type represents a predicate vector used for conditional operations. Each bit corresponds to a lane in the vector.